
.autocomplete-suggestion {
    padding: 2px 5px;
    white-space: nowrap;
}

.autocomplete-suggestion:hover {
    cursor: pointer;
}

.autocomplete-selected {
    background: #F0F0F0;
}

.autocomplete-group {
    padding: 2px 5px;
}

.autocomplete-group strong {
    display: block;
    border-bottom: 1px solid #000;
}

.autocomplete-suggestions {
    border: 1px solid #999;
    background: #FFF;
    overflow: auto;
}

.autocomplete-suggestions strong {
    font-weight: bold;
    color: #d58512;
}
